@@ -233,22 +233,42 @@ retry:
 	return ret;
 }
 
-int
-s_read_file(STREAM * s,void * data,int len)
+typedef struct do_read_file_t {
+	STREAM *	s;
+	void *		data;
+	int		len;
+	int		ret;
+} DO_READ_FILE_T;
+
+void
+s_do_read_file(DO_READ_FILE_T * arg)
 {
 int ret;
 int cnt;
+STREAM * s;
+void * data;
+int len;
 
-unsigned int ip;
-
+	s = arg->s;
+	data = arg->data;
+	len = arg->len;
 retry:
 	errno = 0;
 	ret = read(s->file.fid,data,len);
 	if ( ret < 0 && errno == EINTR && s->h.tbl )
 		goto retry;
-// server debug
-//write(1,data,ret);
-	return ret;
+	arg->ret = ret;
+}
+
+int
+s_read_file(STREAM * s,void * data,int len)
+{
+DO_READ_FILE_T d;
+	d.s = s;
+	d.data = data;
+	d.len = len;
+	ss_do(s_do_read_file,&d);
+	return d.ret;
 }
 
 int
