@@ -1305,12 +1305,10 @@ set_opac_mode();
 void
 opac_move()
 {
-ss_printf("0P_MOVE\n");
 	del_tick(set_opac_mode);
 	lock_task(opac_lock);
 	_opac_move();
 	unlock_task(opac_lock,"opac_move");
-ss_printf("0P_MOVE end\n");
 }
 
 
@@ -1320,7 +1318,6 @@ __opac_stop()
 
 	lock_task(interface_lock);
 
-printf("OPAC STOP\n");
 	if ( cflame.ss.buf_32 ) {
 		d_f_ree(cflame.ss.buf_32);
 		cflame.ss.buf_32 = 0;
@@ -1384,13 +1381,11 @@ void * mp;
 void
 opac_stop()
 {
-ss_printf("0P_STOP\n");
 
 	del_tick(set_opac_mode);
 	lock_task(opac_lock);
 	_opac_stop();
 	unlock_task(opac_lock,"opac_stop");
-ss_printf("0P_STOP END\n");
 }
 
 void
@@ -1411,12 +1406,10 @@ int size;
 void
 set_opac_mode(MOVE_SET * ms)
 {
-ss_printf("SET_0P_MODE\n");
 	del_tick(set_opac_mode);
 	lock_task(opac_lock);
 	_set_opac_mode(ms);
 	unlock_task(opac_lock,"set_opac_mode");
-ss_printf("SET_OP_MODE END\n");
 }
 
 int
@@ -2019,7 +2012,6 @@ GBVIEW_PLANE gbp2;
 		checkin_seq(gbp->h.seq);
 		set_plane_trans(gbp);
 
-printf("REDRAW SELECT\n");
 
 
 		v_redraw_image(cflame.im);
@@ -2040,14 +2032,13 @@ printf("REDRAW SELECT\n");
 	checkin_seq(seq);
 
 	set_plane(&gbp2);
-	if ( gbp2.r.r.tl.x != gbp2.r.r.br.x )
-{printf("REDRAW SELECT 2\n");
+	if ( gbp2.r.r.tl.x != gbp2.r.r.br.x ) {
 
 		v_part_redraw_image(cflame.im,
 			gbp2.r.r.tl.x,gbp2.r.r.tl.y,
 			gbp2.r.r.br.x - gbp2.r.r.tl.x,
 			gbp2.r.r.br.y - gbp2.r.r.tl.y);
-}
+	}
 
 	wf_free_plane(&gbp2);
 	wf_free_status(&sts);
@@ -2116,7 +2107,6 @@ set_cpu_msg(1);
 	case VES_BUTTON_PRESS:
 set_cpu_msg(2);
 
-printf("============================ PRESS\n");
 
 		cflame.mode = GBM_PRESS_IMAGE;
 		cflame.press_x = x;
@@ -2158,7 +2148,6 @@ set_cpu_msg(3);
 		set_opac_mode(0);
 		break;
 	case VES_BUTTON_MOTION:
-ss_printf("MOTION %i - %i %i\n",motion_cnt ++,cflame.mode,cflame.select_mode);
 
 		if ( cflame.mode == GBM_PRESS_IMAGE &&
 				cflame.select_mode == MODE_ROTATE ) {
@@ -2181,13 +2170,11 @@ ss_printf("MOTION %i - %i %i\n",motion_cnt ++,cflame.mode,cflame.select_mode);
 		}
 		else if ( cflame.mode == GBM_PRESS_IMAGE &&
 				cflame.select_mode == MODE_GRAB ) {
-ss_printf("MOTION GRAB-1 %i\n",motion_cnt ++);
 			if ( check_event(cflame.im->header.win,
 				VE_BUTTON,VES_BUTTON_MOTION) )
 				return;
 
 
-ss_printf("MOTION GRAB-2 %i\n",motion_cnt ++);
 
 			cflame.press_x = x;
 			cflame.press_y = y;
@@ -2387,9 +2374,6 @@ VPOINT p;
 int i;
 static XL_INTERPRETER * xli;
 
-if ( subtype == VES_BUTTON_PRESS )
-printf("========================*****");
-printf("BTN SUBTYPE %i - %i\n",subtype,VES_BUTTON_PRESS);
 	if ( xli == 0 ) {
 		xli = new_xl_interpreter();
 		xli->a_type = XLA_SELF;
@@ -2577,7 +2561,6 @@ char * page;
 void
 interface_info_func(int type,GBVIEW_STATUS * sts)
 {
-printf("INFO_FUNC\n");
 	if ( sts->flags & SF_REFERENCE )
 		set_change_page(n_string(std_cm,sts->reference),1);
 	else if ( sts->flags & SF_INFOLIST )
