@@ -20,6 +20,7 @@
 #include	<stdio.h>
 #include	"xl.h"
 #include	"rcache.h"
+#include	"memory_debug.h"
 
 int
 _main(int argc,char ** argv)
@@ -32,6 +33,10 @@ extern int view_agent_switch;
 		exit(1);
 	}
 	if ( strcmp(argv[1],"v") == 0 ) {
+		init_sg();
+
+		init_d_alloc();
+
 		view_init(argc,argv);
 		init_http_server();
 		init_interface();
@@ -50,6 +55,8 @@ extern int view_agent_switch;
 
 		if ( view_agent_switch == 0 )
 			start_gbview();
+		end_sg();
+
 		event_task();
 	}
 	else if ( strcmp(argv[1],"i") == 0 ||
