@@ -40,7 +40,7 @@ XL_SEXP * t;
 		return 0;
 	ret = d_alloc(sizeof(int)*(len+1),1);
 	i = 1;
-	for ( ; get_type(s) ; s = cdr(s) , i ++ ) {
+	for ( ; get_type(s) == XLT_PAIR ; s = cdr(s) , i ++ ) {
 		t = car(s);
 		if ( get_type(t) != XLT_INTEGER )
 			goto err;
