@@ -26,6 +26,7 @@
 #include	"resource.h"
 #include	"pri_level.h"
 #include	"rt_cache.h"
+#include	"save_global.h"
 
 
 #define MIN_CACHE_EXPIRE	60
@@ -61,6 +62,21 @@ SYS_QUEUE	rr_que1,rr_que2;
 
 MP_ROUTE_T * wait_list;
 
+
+void
+routing_global()
+{
+	SG_TITLE;
+
+	sg("SEM",		"route_lock",		&route_lock);
+	sg("MP_ROUTE_T*",	"wait_list",		&wait_list);
+	sg("MP_CACHE",		"direct",		&direct);
+	sg("MP_CACHE",		"indirect",		&indirect);
+	sg("SYS_QUEUE",		"rr_que1",		&rr_que1);
+	sg("SYS_QUEUE",		"rr_que2",		&rr_que2);
+}
+
+
 void
 init_mp_cache(MP_CACHE * c)
 {
@@ -111,6 +127,8 @@ void gc_gb_sexp();
 	setup_queue(&rr_que2);
 
 	new_tick(err_route_tick,10,0);
+	
+	routing_global();
 }
 
 void
@@ -481,6 +499,7 @@ MP_ROUTE * r;
 		for ( ; r != cc->root && r->lock ; r = r->prev );
 		if ( r == cc->root )
 			er_panic("_new_route");
+		delete_rring(r);
 		free_path(r);
 		insert_rring(cc,r);
 		r->flags = 0;
@@ -922,7 +941,6 @@ int _sts;
 	ret->lwait = 0;
 	ret->sts = RS_OK;
 	*sts = RI_INDIRECT;
-	ret->lock ++;
 	return ret;
 }
 
@@ -1097,6 +1115,8 @@ L_CHAR * tmp;
 	if ( b_start && b_target && l_strcmp(b_start,b_target) ) {
 ss_printf("RESOLVE_ERROR %ls %ls\n",n->start,n->target);
 		n->flags |= RQT_ROUTE_ERR;
+		purge_rs_cache(n->start);
+		purge_rs_cache(n->target);
 		return;
 	}
 	cmp = l_strcmp(n->start,n->target);
@@ -1528,6 +1548,7 @@ int sts;
 	if ( wait_flag == RR_WM_NO_WAIT ) {
 		goto end;
 	}
+	_flush_route(ret);
 	_wait_mp_route(n);
 /*
 ss_printf("STS %x %x\n",n,n->flags);
@@ -1601,7 +1622,7 @@ MP_PATH * crd_prev, * map, * crd_next;
 URL uu;
 RESOURCE * r;
 int len;
-int ret;
+int ret,_ret;
 
 LOAD_RESOURCE_WORK * w, * wp;
 
@@ -1631,15 +1652,25 @@ set_t_msg(2000);
 			print_mpr(mpr);
 			er_panic("get_mh_from_route");
 		}
-		if ( resource_check(crd_prev->url,LRO_UNIT) == 0 )
+		_ret = resource_check(crd_prev->url,LRO_UNIT);
+		if ( _ret == CRS_EXIST )
 			continue;
-		ret = CRT_LOADING_RES;
-		if ( loading_flag ) {
+		if ( _ret != CRS_LOADING && loading_flag ) {
 			w = new_lrw(w);
 			get_url2(&w->url,crd_prev->url,1614);
 			w->option = LRO_UNIT;
 			w->err = LRWE_HANDLING;
 		}
+		switch ( _ret ) {
+		case CRS_LOADING:
+			ret = CRT_LOADING_RES;
+			break;
+		case CRS_NOTHING:
+			ret = CRT_ROUTING_EXIST;
+			break;
+		default:
+			ret = _ret;
+		}
 	}
 
 set_t_msg(2001);
@@ -1664,23 +1695,28 @@ set_t_msg(2001);
 			print_mpr(mpr);
 			er_panic("get_mh_from_route");
 		}
-		if ( resource_check(map->url,0) == 0 )
+		_ret = resource_check(map->url,0);
+		if ( _ret == CRS_EXIST )
 			continue;
-		ret = CRT_LOADING_RES;
-		if ( loading_flag ) {
+		if ( _ret != CRS_LOADING && loading_flag ) {
 			w = new_lrw(w);
 			get_url2(&w->url,map->url,1614);
 			w->err = LRWE_HANDLING;
 		}
+		switch ( _ret ) {
+		case CRS_LOADING:
+			ret = CRT_LOADING_RES;
+			break;
+		case CRS_NOTHING:
+			ret = CRT_ROUTING_EXIST;
+			break;
+		default:
+			ret = _ret;
+		}
 	}
-	if ( loading_flag ) {
-		if ( w )
+	if ( w )
 		load_resource_list(w,Q_PRI_ROUTING,0);
-		return ret;
-	}
-	else {
-		return ret;
-	}
+	return ret;
 }
 
 MAP_HISTORY *
