@@ -27,6 +27,11 @@
 #include	"pri_level.h"
 
 
+typedef struct indicate_t {
+	Q_HEADER		h;
+	RESOURCE *		r;
+} INDICATE_T;
+
 
 #define IRQ_MAX		20
 
@@ -40,6 +45,8 @@ SEM iom_lock;
 int irq_cnt;
 int indicate_cnt;
 NESTED_LOCK * indicate_nlock;
+SYS_QUEUE	req_indicate;
+
 
 void
 init_indicate()
@@ -48,6 +55,15 @@ init_indicate()
 	irq_lock = new_lock(LL_IRQ);
 	iom_lock = new_lock(LL_ONMAP);
 	indicate_nlock = new_nlock();
+
+	memset(&req_indicate,0,sizeof(SYS_QUEUE));
+	req_indicate.flags = QF_FIFO;
+	req_indicate.gc_func = 0;
+	req_indicate.gc_get = 0;
+	req_indicate.key_func = 0;
+	req_indicate.pri = PRI_FETCH_STRONG;
+	setup_queue(&req_indicate);
+	
 	create_task(indicate_info_task,0,PRI_FETCH_STRONG);
 }
 
@@ -379,6 +395,7 @@ void
 insert_irq(RESOURCE * r,int code,int cmd,WF_ID wfid)
 {
 INFO_REQ_QUEUE * ir;
+INDICATE_T * it;
 	lock_task(irq_lock);
 	ir = d_alloc(sizeof(*ir),235);
 	ir->code = code;
@@ -390,6 +407,11 @@ printf("??????????????? insert_irq\n");
 	r->draw_gb.ir_queue = ir;
 	irq_cnt ++;
 	unlock_task(irq_lock,"insert_irq");
+
+	it = d_alloc(sizeof(*it),22);
+	memset(it,0,sizeof(*it));
+	it->r = r;
+	insert_queue(&req_indicate,it,1);
 }
 
 void
@@ -928,7 +950,7 @@ check_irq(int ses,RESOURCE * r)
 {
 XL_SEXP * query, * code;
 INFO_REQ_QUEUE * ir1, * ir2;
-XL_SEXP * ret;
+XL_SEXP * ret,* all;
 int er;
 XL_SEXP * gvr;
 char buf[32];
@@ -938,6 +960,7 @@ int cnt;
 int req;
 OBJ * o;
 L_CHAR * f;
+int setup_ret;
 
 	lock_task(indicate_lock);
 	lock_task(irq_lock);
@@ -1015,6 +1038,7 @@ os_test2 = 0;
 		break;
 	case XLT_PAIR:
 		set_inc_status(r,RS_IDLE);
+		for ( all = ret ; get_type(all) == XLT_PAIR ; all = cdr(all) );
 		break;
 	case XLT_NULL:
 		set_inc_status(r,RS_IDLE);
@@ -1036,9 +1060,11 @@ os_test2 = 0;
 		er = -1;
 		goto end;
 	}
-	if ( setup_info(wfid,r,ret) ) {
+	lock_pdb_lock(r,1);
+	setup_ret = setup_info(wfid,r,ret);
+	unlock_pdb_lock(r);
+	if ( setup_ret )
 		_wf_set_redraw();
-	}
 end:
 	gc_pop(0,0);
 	return er;
@@ -1049,10 +1075,10 @@ void
 indicate_info_task()
 {
 XL_INTERPRETER * xli;
-RESOURCE * r;
 int ses;
 int i;
 int f;
+INDICATE_T * it;
 
 printf("indicate task ****  %i\n",get_tid());
 
@@ -1065,27 +1091,13 @@ set_cpu_thr_type(5);
 	ses = open_session(SEST_OPTIMIZE);
 
 	for ( ; ; ) {
-		lock_task(indicate_lock);
-		if ( irq_cnt == 0 ) {
-/*
-printf("indicate sleep %i\n",get_tid());
-*/
-			sleep_task((int)init_indicate,indicate_lock);
-/*
-printf("indicate wakeup %i\n",get_tid());
-*/
-		}
-		else {
-			unlock_task(indicate_lock,"indicate_info_task");
-		}
-		for ( i = 0 ; i < RES_HASH_SIZE ; i ++ ) {
-			r = res_entry_hash_table[i];
-			for ( ; r ; r = r->h.entry_next ) {
-				if ( r->h.type != RT_DRAW_GB )
-					continue;
-				check_irq(ses,r);
-			}
-		}
+		it = delete_queue(&req_indicate,0,0,1);
+		if ( it == 0 )
+			continue;
+		if ( it->r->h.type != RT_DRAW_GB )
+			er_panic("indicate_info_task");
+		check_irq(ses,it->r);
+		d_f_ree(it);
 	}
 }
 
