@@ -18,12 +18,13 @@
 
 #include	"memory_debug.h"
 #include	"pdb.h"
+#include	"utils.h"
 
 
 void
 close_pdb(PDB * p)
 {
-	close(p->fid);
+	u_close(p->fid);
 	close_file(p->cache);
 	free_request(p->next_request);
 	free_request(p->request);
