@@ -34,6 +34,7 @@
 #define ACCEPT_RET_MAX			120
 #define ACCEPT_RET_TIMEOUT		10
 #define ACCEPT_RET_DEC_INTERVAL		120
+#define CR_SEND_INTERVAL		30
 
 typedef struct lock_function_type {
 	struct lock_function_type *	next;
@@ -367,6 +368,35 @@ lock_xli_out(XL_INTERPRETER * xli)
 	unlock_task(xli_lock,"lock_xli_out");
 }
 
+int
+_lock_xli_out_no_wait(XL_INTERPRETER * xli)
+{
+int t;
+	if ( xli == 0 )
+		return -1;
+	t = get_tid();
+	if ( xli->out_lock == 0 ) {
+		xli->out_lock = 1;
+		xli->out_lock_task = t;
+		return 0;
+	}
+	if ( xli->out_lock_task == t ) {
+		xli->out_lock ++;
+		return 0;
+	}
+	return -2;
+}
+
+int
+lock_xli_out_no_wait(XL_INTERPRETER * xli)
+{
+int ret;
+	lock_task(xli_lock);
+	ret = _lock_xli_out_no_wait(xli);
+	unlock_task(xli_lock,"lock_xli_out");
+	return ret;
+}
+
 void
 _unlock_xli_out(XL_INTERPRETER * xli)
 {
@@ -2269,7 +2299,17 @@ _tick_check(XL_INTERPRETER * xli)
 		wakeup_task((int)&xli->flags);
 		return;
 	}
+
 	xli->connection_cnt ++;
+	if ( (xli->a_type == XLA_CONNECT ||
+			xli->a_type == XLA_DESCRIPTER) &&
+			(xli->connection_cnt % CR_SEND_INTERVAL) == 0 ) {
+		if ( _lock_xli_out_no_wait(xli) == 0 ) {
+			if ( xli->mode == XIM_RUN && xli->out )
+				s_printf(xli->out,"\n");
+			_unlock_xli_out(xli);
+		}
+	}
 	if ( xli->silent_cnt < 0 ||
 		xli->delay_que_cnt ||
 		(xli->flags&XIF_CTO_LOCK) &&
@@ -2311,6 +2351,7 @@ XL_INTERPRETER * xli;
 				xli = xli->next )
 			_tick_check(xli);
 	unlock_task(xli_lock,"xli_tick");
+
 }
 
 
@@ -2349,21 +2390,14 @@ d_sexp_func(XL_SEXP * s)
 {
 D_SEXP * d;
 
-set_t_msg(5000);
 	lock_task(xli_lock);
-set_t_msg(5001);
 	d = (D_SEXP*)s->delay.d.func;
 	for ( ; !(d->flags & DSF_OK) ; ) {
-set_t_msg(5002);
 		sleep_task((int)d,xli_lock);
 		lock_task(xli_lock);
-set_t_msg(5003);
 	}
-set_t_msg(5004);
 	over_write_sexp(s,d->ret);
-set_t_msg(5005);
 	unlock_task(xli_lock,"d_sexp");
-set_t_msg(5006);
 	return s;
 }
 
