@@ -208,8 +208,6 @@ void gc_gb_sexp();
 CODE_METHOD * cm1;
 
 
-
-
 	my_xli = _get_my_xli();
 	if ( my_xli == 0 )
 		er_panic("_remote_query");
@@ -274,6 +272,17 @@ CODE_METHOD * cm1;
 		_unlock_xli_out(xli);
 		return ret;
 	}
+	if ( xli->out == 0 ) {
+		ret = get_error(
+			resp->file,
+			resp->line,
+			XLE_PROTO_ACCESS_STREAM,
+			l_string(std_cm,"Remote"),
+			n_get_string("output stream error"));
+
+		_unlock_xli_out(xli);
+		return ret;
+	}
 
 	resp->seq_from = xli->out->h.cr_cnt;
 	if ( xli->flags & XIF_CODE_SYNC ) {
@@ -454,20 +463,17 @@ XL_SEXP * ret;
 XL_FILE * file;
 int line;
 
-set_cpu_msg(9810);
-	if ( cmd_sexp == 0 ) {
-		file = 0;
-		line = 0;
-	}
-	else {
+	if ( cmd_sexp ) {
 		file = cmd_sexp->h.file;
 		line = cmd_sexp->h.line;
 	}
-set_cpu_msg(9811);
+	else if ( cmd_str ) {
+		file = 0;
+		line = 0;
+	}
+	else 	return 0;
 	lock_task(xli_lock);
-set_cpu_msg(9812);
 	xli = _search_xli_id(id);
-set_cpu_msg(9813);
 	if ( xli == 0 ) {
 		ret = get_error(
 			file,
@@ -497,12 +503,10 @@ set_cpu_msg(9813);
 		unlock_task(xli_lock,"remote_query");
 		return 0;
 	}
-set_cpu_msg(9814);
 
 	ret = _remote_query(xli,env,cmd_str,cmd_sexp);
 
 end:
-set_cpu_msg(9815);
 	unlock_task(xli_lock,"remote_query");
 
 	return ret;
